==> paraview-5.9.1-5-x86_64.pkg.tar.zst: usr/lib/cmake/paraview/paraview.modules-vtk-python-module-properties.cmake <==
set_property(TARGET "ParaView::IOVisItBridge" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingClientServerStream" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsCore" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingCore" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingServerManager" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingViews" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingViewsPython" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingServerManagerPython" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsPoints" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOCore" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOSPCTH" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOImage" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOExodus" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOEnSight" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOAMR" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersStatistics" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersPython" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersMaterialInterface" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersGeneralMPI" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsExtractionPython" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsConduit" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsCGNSWriter" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsCGNSReader" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingExport" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingLive" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingMisc" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOGeneral" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersGeneral" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsAMR" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingApplication" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingSettings" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingAnimation" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsInteractionStyle" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersRendering" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsMisc" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsExtraction" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::Catalyst" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::AdaptorsPagosa" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::PythonCatalyst" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::ClientsWeb" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::InSitu" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")

==> paraview-6.0.1-8-x86_64.pkg.tar.zst: usr/lib/cmake/paraview/paraview.modules-vtk-python-module-properties.cmake <==
set_property(TARGET "ParaView::IOVisItBridge" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingClientServerStream" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::Versioning" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsCore" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingCore" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingServerManager" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingViews" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingViewsPython" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingServerManagerPython" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsPoints" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOCore" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOSPCTH" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOCGNSWriter" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOParallelCGNSWriter" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOImage" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOExodus" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOEnSight" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOAMR" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersStatistics" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersPython" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersGeneral" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersParallelDIY2" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersParallel" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersMaterialInterface" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersGeneralMPI" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersFlowPaths" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsExtractionPython" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingApplicationComponents" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingImport" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOImport" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsExtraction" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingLive" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingExport" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingMisc" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsIOGeneral" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsAMR" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingApplication" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingAnimation" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsInteractionStyle" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsFiltersRendering" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::VTKExtensionsMisc" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::RemotingSettings" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::Catalyst" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::PythonCatalyst" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::ClientsWeb" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
set_property(TARGET "ParaView::InSitu" PROPERTY "INTERFACE_vtk_module_python_package" "paraview.modules")
